@@ -22,9 +22,9 @@ class Timer:
 
 def progress_bar_str(done, total):
     percent = round(done/total*100, 2)
-    strin = "░░░░░░░░░░░░░░░░░░░░"
+    strin = "░░░░░░░░░░"
     strin = list(strin)
-    for i in range(round(percent)//5):
+    for i in range(round(percent)//10):
         strin[i] = "█"
     strin = "".join(strin)
     final = f"Percent: {percent}%\n{human_readable_size(done)}/{human_readable_size(total)}\n{strin}"
@@ -49,13 +49,13 @@ async def fast_download(client, msg, reply = None, download_folder = None, progr
     filename = msg.file.name
     dir = "downloads/"
 
-    if not os.path.isfile(dir):
-        os.mkdir("downloads/") 
+    try:
+        os.mkdir("downloads/")
+    except:
+        pass
 
     if not filename:
-        filename = (
-            "video_" + dt.now().isoformat("_", "seconds") + ".mp4"
-                    )
+        filename = "video.mp4"
                     
     if download_folder == None:
         download_location = dir + filename
@@ -76,7 +76,6 @@ async def fast_download(client, msg, reply = None, download_folder = None, progr
                 location=file, 
                 out=f,
             )
-    await reply.edit("Finished downloading")
     return download_location
 
 async def fast_upload(client, file_location, reply=None, name=None, progress_bar_function = progress_bar_str):
@@ -103,5 +102,4 @@ async def fast_upload(client, file_location, reply=None, name=None, progress_bar
                 name=name,
             )
         
-    await reply.edit("Finished uploading")
     return the_file
